@@ -7,7 +7,7 @@ const JUSTFILE_NAMES: &[&str] = &["justfile", ".justfile"];
 const PROJECT_ROOT_CHILDREN: &[&str] = &[".bzr", ".git", ".hg", ".svn", "_darcs"];
 
 pub(crate) struct Search {
-  pub(crate) justfile:          PathBuf,
+  pub(crate) justfile: PathBuf,
   pub(crate) working_directory: PathBuf,
 }
 
@@ -18,7 +18,7 @@ impl Search {
   ) -> SearchResult<Self> {
     match search_config {
       SearchConfig::FromInvocationDirectory => {
-        let justfile = Self::justfile(&invocation_directory)?;
+        let justfile = Self::justfile(invocation_directory)?;
 
         let working_directory = Self::working_directory_from_justfile(&justfile)?;
 
@@ -26,7 +26,7 @@ impl Search {
           justfile,
           working_directory,
         })
-      },
+      }
 
       SearchConfig::FromSearchDirectory { search_directory } => {
         let search_directory = Self::clean(invocation_directory, search_directory);
@@ -39,7 +39,7 @@ impl Search {
           justfile,
           working_directory,
         })
-      },
+      }
 
       SearchConfig::WithJustfile { justfile } => {
         let justfile = Self::clean(invocation_directory, justfile);
@@ -50,13 +50,13 @@ impl Search {
           justfile,
           working_directory,
         })
-      },
+      }
 
       SearchConfig::WithJustfileAndWorkingDirectory {
         justfile,
         working_directory,
       } => Ok(Self {
-        justfile:          Self::clean(invocation_directory, justfile),
+        justfile: Self::clean(invocation_directory, justfile),
         working_directory: Self::clean(invocation_directory, working_directory),
       }),
     }
@@ -68,7 +68,7 @@ impl Search {
   ) -> SearchResult<Self> {
     match search_config {
       SearchConfig::FromInvocationDirectory => {
-        let working_directory = Self::project_root(&invocation_directory)?;
+        let working_directory = Self::project_root(invocation_directory)?;
 
         let justfile = working_directory.join(DEFAULT_JUSTFILE_NAME);
 
@@ -76,7 +76,7 @@ impl Search {
           justfile,
           working_directory,
         })
-      },
+      }
 
       SearchConfig::FromSearchDirectory { search_directory } => {
         let search_directory = Self::clean(invocation_directory, search_directory);
@@ -89,7 +89,7 @@ impl Search {
           justfile,
           working_directory,
         })
-      },
+      }
 
       SearchConfig::WithJustfile { justfile } => {
         let justfile = Self::clean(invocation_directory, justfile);
@@ -100,13 +100,13 @@ impl Search {
           justfile,
           working_directory,
         })
-      },
+      }
 
       SearchConfig::WithJustfileAndWorkingDirectory {
         justfile,
         working_directory,
       } => Ok(Self {
-        justfile:          Self::clean(invocation_directory, justfile),
+        justfile: Self::clean(invocation_directory, justfile),
         working_directory: Self::clean(invocation_directory, working_directory),
       }),
     }
@@ -134,10 +134,10 @@ impl Search {
         }
       }
 
-      if candidates.len() == 1 {
-        return Ok(candidates.into_iter().next().unwrap());
-      } else if candidates.len() > 1 {
-        return Err(SearchError::MultipleCandidates { candidates });
+      match candidates.len() {
+        0 => {}
+        1 => return Ok(candidates.into_iter().next().unwrap()),
+        _ => return Err(SearchError::MultipleCandidates { candidates }),
       }
     }
 
@@ -174,7 +174,7 @@ impl Search {
           io_error,
           directory: directory.to_owned(),
         })?;
-        for project_root_child in PROJECT_ROOT_CHILDREN.iter().cloned() {
+        for project_root_child in PROJECT_ROOT_CHILDREN.iter().copied() {
           if entry.file_name() == project_root_child {
             return Ok(directory.to_owned());
           }
@@ -206,7 +206,7 @@ mod tests {
   fn not_found() {
     let tmp = testing::tempdir();
     match Search::justfile(tmp.path()) {
-      Err(SearchError::NotFound) => {},
+      Err(SearchError::NotFound) => {}
       _ => panic!("No justfile found error was expected"),
     }
   }
@@ -226,7 +226,7 @@ mod tests {
     fs::write(&path, "default:\n\techo ok").unwrap();
     path.pop();
     match Search::justfile(path.as_path()) {
-      Err(SearchError::MultipleCandidates { .. }) => {},
+      Err(SearchError::MultipleCandidates { .. }) => {}
       _ => panic!("Multiple candidates error was expected"),
     }
   }
@@ -301,7 +301,7 @@ mod tests {
         path.pop();
         path.push(DEFAULT_JUSTFILE_NAME);
         assert_eq!(found_path, path);
-      },
+      }
       Err(err) => panic!("No errors were expected: {}", err),
     }
   }
